Gestione giocatori — SoL 3, manuale utente

### Navigazione

- indice
- successivo |
- precedente |
- Manuale d'uso »
- Interfaccia utente »
- Anagrafiche di base »

# Gestione giocatori

I giocatori sono chiaramente il fulcro di tutto il sistema, primariamente nell’ottica della loro partecipazione ai tornei, ma anche come potenziali utenti del sistema stesso: quando a un giocatore viene assegnato un soprannome e una password sarà in grado di connettersi al sistema e di inserire nuovi giocatori, campionati, tornei e così via.

## Voci del menu

Oltre alle azioni standard il menu contiene queste voci:

Gestione giocatori

Tornei
  Apre la gestione dei tornei a cui ha partecipato il giocatore selezionato
Duplicati
  Passa dal normale elenco dei giocatori a quello dei potenziali duplicati
Distribuzione
  Mostra la distribuzione dei giocatori in giro per il mondo

## Inserimento e modifica

Il nome e il cognome di un giocatore sono dati obbligatori, mentre il soprannome è facoltativo e viene usato sia come account, insieme all’eventuale password, che per disambiguare gli omonimi. Quando vengono memorizzate le modifiche SoL esegue una verifica sui nomi già presenti nel database, per evitare doppioni, per quanto possibile.

I campi sesso, data di nascita, nazionalità e club sono opzionali e vengono usati per produrre vari tipi di classifica, mentre la lingua e l’email per eventuali messaggi inviati per posta elettronica.

Generalmente per poter partecipare a tornei internazionali è richiesta la cittadinanza per il paese per cui si gioca, oltre all’iscrizione alla federazione del medesimo paese.

Il responsabile generalmente indica l’utente che ha inserito quel particolare nominativo: i dati del giocatore potranno essere modificati solo da lui (oltre che dall’amministratore del sistema.).

Al giocatore può essere assegnata un’immagine (nei formati `.png`, `.jpg` o `.gif`) utilizzata come ritratto nella sua pagina personale. Sebbene venga automaticamente scalata alla bisogna, si raccomanda di usare immagini di dimensioni ragionevoli (di fatto il programma impone un limite di 256Kb).

## Iscrizione al torneo

Iscrizione altri giocatori

Quando si sta preparando un nuovo torneo e si procede con l’iscrizione dei giocatori, dall’apposita voce aggiungi... nel menu del Pannello concorrenti della Gestione torneo si accede alla maschera dei giocatori, da dove è possibile selezionare uno o più giocatori (possibilmente estendendo la selezione usando i classici `shift`-click e `ctrl`-click).

La maschera viene filtrata automaticamente per mostrare solo i giocatori non ancora iscritti al torneo in questione.

Per aggiungere i giocatori selezionati al torneo si possono sia trascinare nel pannello sinistro della gestione torneo, o più semplicemente si può usare il pulsante Inserisci giocatori selezionati, se presente.

## Doppia registrazione di un giocatore

Giocatori potenzialmente duplicati

Talvolta un giocatore viene inserito nel database due (o più) volte con nomi leggermente diversi, per errore o incomprensione. Il caso tipico è quello di un particolare giocatore che partecipa a diversi tornei: essendo identificato in maniera non univoca, i suoi risultati non possono essere riassunti correttamente nella classifica del campionato, dove appare più volte con le sue varie identità.

In questa situazione è necessario eseguire una correzione ai dati, sostituendo le varie identità con una unica, in tutti i tornei dove ha partecipato. Infine, le identità sbagliate devono essere cancellate dal database.

Questo può essere fatto selezionando le identità sbagliate e trascinandole sopra quella giusta mantenendo premuto il tasto `ALT`. È necessario ovviamente fare in modo che tutti i giocatori interessati siano visibili allo stesso momento applicando un filtro opportuno, eventualmente inserendo un marcatore temporaneo (tipo **) nel cognome dei giocatori su cui si intende operare e filtrando su quello.

L’applicazione verificherà che l’operazione non generi alcun conflitto, segnalando un errore ad esempio quando in uno stesso torneo risulti presente sia il nome giusto che uno di quelli sbagliati.

Per facilitare il compito, può tornare comoda la voce Duplicati nel menu, che applica un filtro particolare all’elenco dei giocatori evidenziando quelli che potrebbero essere dei duplicati: in sostanza vengono confrontati i nomi e cognomi dei giocatori e vengono mostrati solo i giocatori che hanno nomi molto simili tra loro, tipicamente perché differiscono solo per poche lettere.

Avvertimento

Non eseguire questa operazione mentre si sta preparando un nuovo torneo, perché i dati modificati e non ancora memorizzati potrebbero facilmente risultare non più corretti: la finestra di gestione del torneo deve essere chiusa!

### Navigazione

- indice
- successivo |
- precedente |
- Manuale d'uso »
- Interfaccia utente »
- Anagrafiche di base »